import click

from . import base


@base.cli.group()
@click.pass_context
def favorites(ctx):
    pass


@favorites.group("tracks")
@click.pass_context
def favorites_tracks(ctx):
    pass


@favorites_tracks.command("create")
@click.argument("id", nargs=-1, required=True)
@click.pass_context
@base.async_command
async def favorites_tracks_create(ctx, id):
    click.echo("Adding {} tracks to favorites…".format(len(id)))

    async with ctx.obj["remote"]:
        for i in id:
            data = {"track": i}
            async with ctx.obj["remote"].request(
                "post", "api/v1/favorites/tracks/", data=data
            ) as response:
                response.raise_for_status()
                click.echo("Track {} added to favorites".format(i))


@favorites_tracks.command("rm")
@click.argument("id", nargs=-1, required=True)
@click.pass_context
@base.async_command
async def favorites_tracks_rm(ctx, id):
    click.echo("Removing {} tracks to favorites…".format(len(id)))

    async with ctx.obj["remote"]:
        for i in id:
            data = {"track": i}
            async with ctx.obj["remote"].request(
                "delete", "api/v1/favorites/tracks/remove/", data=data
            ) as response:
                response.raise_for_status()
                click.echo("Track {} removed from favorites".format(i))


favorites_tracks_ls = base.get_ls_command(  # noqa
    favorites_tracks,
    "api/v1/favorites/tracks/",
    output_conf={
        "labels": ["Track ID", "Track", "Artist", "Favorite Date"],
        "type": "TRACK_FAVORITE",
    },
)
