import click
import json

from . import base
from .. import output


@base.cli.group()
@click.pass_context
def libraries(ctx):
    """
    Manage libraries
    """


libraries_ls = base.get_ls_command(
    libraries,
    "api/v1/libraries/",
    output_conf={
        "labels": ["UUID", "Name", "Visibility", "Uploads"],
        "type": "LIBRARY",
    },
)
libraries_rm = base.get_delete_command(libraries, "api/v1/libraries/{}/")


@libraries.command("create")
@click.option("--name", prompt=True)
@click.option(
    "--visibility",
    type=click.Choice(["me", "instance", "everyone"]),
    default="me",
    prompt=True,
)
@click.option("--raw", is_flag=True)
@click.pass_context
@base.async_command
async def libraries_create(ctx, raw, name, visibility):
    async with ctx.obj["remote"]:
        result = await ctx.obj["remote"].request(
            "post", "api/v1/libraries/", data={"name": name, "visibility": visibility}
        )
        result.raise_for_status()
        payload = await result.json()
    if raw:
        click.echo(json.dumps(payload, sort_keys=True, indent=4))
    else:
        click.echo("Library created:")
        click.echo(
            output.table([payload], ["UUID", "Name", "Visibility"], type="LIBRARY")
        )
