import json

import click

from . import base
from .. import api


@base.cli.group()
@click.pass_context
def server(ctx):
    pass


@server.command()
@base.RAW_DECORATOR
@click.pass_context
@base.async_command
async def info(ctx, raw):
    async with api.get_session() as session:
        nodeinfo = await api.fetch_nodeinfo(
            session,
            domain=ctx.obj["SERVER_NETLOC"],
            protocol=ctx.obj["SERVER_PROTOCOL"],
        )
    if raw:
        click.echo(json.dumps(nodeinfo, sort_keys=True, indent=4))
        return
    click.echo("\n")
    click.echo("General")
    click.echo("-------")
    click.echo("Url:                {}".format(ctx.obj["SERVER_URL"]))
    click.echo("Name:               {}".format(nodeinfo["metadata"]["nodeName"]))
    click.echo(
        "Short description:  {}".format(nodeinfo["metadata"]["shortDescription"])
    )
    click.echo("\n")
    click.echo("Software")
    click.echo("----------")
    click.echo("Software name:      {}".format(nodeinfo["software"]["name"]))
    click.echo("Version:            {}".format(nodeinfo["software"]["version"]))
    click.echo("\n")
    click.echo("Configuration")
    click.echo("---------------")
    click.echo(
        "Registrations:      {}".format(
            "open" if nodeinfo["openRegistrations"] else "closed"
        )
    )
